summaryrefslogtreecommitdiffstats
path: root/kicker/menuext/konsole
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2024-01-12 10:51:50 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2024-01-16 10:03:43 +0900
commita4241b7911d2e0b36edfb02f616b8b282050c0ec (patch)
tree316c9a3298857645d5da57b682fce707c8e2a907 /kicker/menuext/konsole
parentf9d06cee3d2b4ffe415b1d52c9ad5575643a9e34 (diff)
downloadtdebase-a4241b7911d2e0b36edfb02f616b8b282050c0ec.tar.gz
tdebase-a4241b7911d2e0b36edfb02f616b8b282050c0ec.zip
Use new TQ_METHOD, TQ_SIGNAL, TQ_SLOT defines
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'kicker/menuext/konsole')
-rw-r--r--kicker/menuext/konsole/konsole_mnu.cpp8
-rw-r--r--kicker/menuext/konsole/konsolebookmarkhandler.cpp16
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.cpp16
3 files changed, 20 insertions, 20 deletions
diff --git a/kicker/menuext/konsole/konsole_mnu.cpp b/kicker/menuext/konsole/konsole_mnu.cpp
index c9439c8db..2e196186f 100644
--- a/kicker/menuext/konsole/konsole_mnu.cpp
+++ b/kicker/menuext/konsole/konsole_mnu.cpp
@@ -150,8 +150,8 @@ void KonsoleMenu::initialize()
insertItem(SmallIconSet("keditbookmarks"),
i18n("New Session at Bookmark"), m_bookmarksSession);
connect(m_bookmarkHandlerSession,
- TQT_SIGNAL(openURL(const TQString&, const TQString&)),
- TQT_SLOT(newSession(const TQString&, const TQString&)));
+ TQ_SIGNAL(openURL(const TQString&, const TQString&)),
+ TQ_SLOT(newSession(const TQString&, const TQString&)));
screenList.clear();
@@ -229,11 +229,11 @@ void KonsoleMenu::initialize()
// we don't have any profiles, disable the menu
setItemEnabled(profileID, false);
}
- connect(m_profileMenu, TQT_SIGNAL(activated(int)), TQT_SLOT(launchProfile(int)));
+ connect(m_profileMenu, TQ_SIGNAL(activated(int)), TQ_SLOT(launchProfile(int)));
insertSeparator();
insertItem(SmallIconSet("reload"),
- i18n("Reload Sessions"), this, TQT_SLOT(reinitialize()));
+ i18n("Reload Sessions"), this, TQ_SLOT(reinitialize()));
}
void KonsoleMenu::slotExec(int id)
diff --git a/kicker/menuext/konsole/konsolebookmarkhandler.cpp b/kicker/menuext/konsole/konsolebookmarkhandler.cpp
index 9ace6483e..b2249d858 100644
--- a/kicker/menuext/konsole/konsolebookmarkhandler.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkhandler.cpp
@@ -38,8 +38,8 @@ KonsoleBookmarkHandler::KonsoleBookmarkHandler( KonsoleMenu *konsole, bool )
manager->setUpdate( true );
manager->setShowNSBookmarks( false );
- connect( manager, TQT_SIGNAL( changed(const TQString &, const TQString &) ),
- TQT_SLOT( slotBookmarksChanged(const TQString &, const TQString &) ) );
+ connect( manager, TQ_SIGNAL( changed(const TQString &, const TQString &) ),
+ TQ_SLOT( slotBookmarksChanged(const TQString &, const TQString &) ) );
m_bookmarkMenu = new KonsoleBookmarkMenu( manager, this, m_menu,
NULL, false, /*Not toplevel*/
false /*No 'Add Bookmark'*/ );
@@ -62,13 +62,13 @@ void KonsoleBookmarkHandler::importOldBookmarks( const TQString& path,
KNSBookmarkImporter importer( path );
connect( &importer,
- TQT_SIGNAL( newBookmark( const TQString&, const TQCString&, const TQString& )),
- TQT_SLOT( slotNewBookmark( const TQString&, const TQCString&, const TQString& )));
+ TQ_SIGNAL( newBookmark( const TQString&, const TQCString&, const TQString& )),
+ TQ_SLOT( slotNewBookmark( const TQString&, const TQCString&, const TQString& )));
connect( &importer,
- TQT_SIGNAL( newFolder( const TQString&, bool, const TQString& )),
- TQT_SLOT( slotNewFolder( const TQString&, bool, const TQString& )));
- connect( &importer, TQT_SIGNAL( newSeparator() ), TQT_SLOT( newSeparator() ));
- connect( &importer, TQT_SIGNAL( endMenu() ), TQT_SLOT( endMenu() ));
+ TQ_SIGNAL( newFolder( const TQString&, bool, const TQString& )),
+ TQ_SLOT( slotNewFolder( const TQString&, bool, const TQString& )));
+ connect( &importer, TQ_SIGNAL( newSeparator() ), TQ_SLOT( newSeparator() ));
+ connect( &importer, TQ_SIGNAL( endMenu() ), TQ_SLOT( endMenu() ));
importer.parseNSBookmarks( false );
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.cpp b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
index 52588ed72..840b3b8f6 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
* They are named differently because the TQT_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect( _parentMenu, TQT_SIGNAL( aboutToShow() ), this,
- TQT_SLOT( slotAboutToShow() ) );
- connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
- TQT_SLOT( slotAboutToShow2() ) );
+ disconnect( _parentMenu, TQ_SIGNAL( aboutToShow() ), this,
+ TQ_SLOT( slotAboutToShow() ) );
+ connect( _parentMenu, TQ_SIGNAL( aboutToShow() ),
+ TQ_SLOT( slotAboutToShow2() ) );
}
/*
@@ -100,8 +100,8 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
m_actionCollection, false,
m_bAddBookmark, TQString::null );
m_lstSubMenus.append(subMenu);
- connect( actionMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), subMenu,
- TQT_SLOT(slotNSLoad()));
+ connect( actionMenu->popupMenu(), TQ_SIGNAL(aboutToShow()), subMenu,
+ TQ_SLOT(slotNSLoad()));
}
}
@@ -128,7 +128,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
TDEAction * action = new TDEAction( text, bm.icon(), 0,
- this, TQT_SLOT( slotBookmarkSelected() ),
+ this, TQ_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
- * They are named differently because the TQT_SLOT() macro thinks we want
+ * They are named differently because the TQ_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?